from setuptools import setup

from distutils.core import setup
setup(
  name = 'credulous',
  packages = ['credulous'], # this must be the same as the name above
  version = '0.1.2',
  description = 'Tool for generating API credentials. Google API is supported.',
  author = 'Bo Ogunlana',
  author_email = 'foluso@brainlabsdigital.com',
  url = 'https://github.com/bo-brainlabs/pycredulous', # use the URL to the github repo
  keywords = ['oauth2', 'authentication', 'google', 'googleads-api-client-python'], # arbitrary keywords
  classifiers = [],
  install_requires = [
  	'google-api-python-client',
		'oauth2client',
  ]
)